@@ -30,6 +30,7 @@
 #include <locale.h>
 #include "nautilus-file-operations.h"
 
+#include "nautilus-debug-log.h"
 #include "nautilus-file-operations-progress.h"
 #include "nautilus-lib-self-check-functions.h"
 
@@ -444,7 +445,7 @@ progress_dialog_set_to_from_item_text (NautilusFileOperationsProgress *dialog,
 			from_path [length - 1] = '\0';
 		}
 
-		if (!gnome_vfs_uri_is_local (uri)) {
+		if (strcmp (uri->method_string, "file") != 0) {
 			hostname = gnome_vfs_uri_get_host_name (uri);
 		}
 		if (hostname) {
@@ -473,7 +474,7 @@ progress_dialog_set_to_from_item_text (NautilusFileOperationsProgress *dialog,
 			to_path [length - 1] = '\0';
 		}
 
-		if (!gnome_vfs_uri_is_local (uri)) {
+		if (strcmp (uri->method_string, "file") != 0) {
 			hostname = gnome_vfs_uri_get_host_name (uri);
 		}
 		if (hostname) {
@@ -1907,6 +1908,33 @@ nautilus_file_operations_copy_move (const GList *item_uris,
 
 	g_assert (item_uris != NULL);
 
+	{
+		const char *action_str;
+
+		switch (copy_action) {
+		case GDK_ACTION_COPY:
+			action_str = "copy";
+			break;
+
+		case GDK_ACTION_MOVE:
+			action_str = "move";
+			break;
+
+		case GDK_ACTION_LINK:
+			action_str = "link";
+			break;
+
+		default:
+			action_str = "[unknown action]";
+			break;
+		}
+
+		nautilus_debug_log_with_uri_list (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER, item_uris,
+						  "%s the following URIs to \"%s\":",
+						  action_str,
+						  target_dir ? target_dir : "[empty location]");
+	}
+
 	target_dir_uri = NULL;
 	trash_dir_uri = NULL;
 	result = GNOME_VFS_OK;
@@ -1916,6 +1944,12 @@ nautilus_file_operations_copy_move (const GList *item_uris,
 	if (target_dir != NULL) {
 		if (eel_uri_is_trash (target_dir)) {
 			target_is_trash = TRUE;
+		} else if (eel_uri_is_desktop (target_dir)) {
+			char *desktop_dir_uri;
+
+			desktop_dir_uri = nautilus_get_desktop_directory_uri ();
+			target_dir_uri = gnome_vfs_uri_new (desktop_dir_uri);
+			g_free (desktop_dir_uri);
 		} else {
 			target_dir_uri = gnome_vfs_uri_new (target_dir);
 		}
@@ -2368,10 +2402,23 @@ nautilus_file_operations_new_folder (GtkWidget *parent_view,
 	NewFolderTransferState *state;
 	SyncTransferInfo *sync_transfer_info;
 
-	/* pass in the target directory and the new folder name as a destination URI */
-	parent_uri = gnome_vfs_uri_new (parent_dir);
-	/* localizers: the initial name of a new folder  */
+	g_assert (parent_dir != NULL);
 
+	nautilus_debug_log (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER,
+			    "create an untitled folder in \"%s\"", parent_dir);
+
+	/* pass in the target directory and the new folder name as a destination URI */
+	if (eel_uri_is_desktop (parent_dir)) {
+		char *desktop_dir_uri;
+
+		desktop_dir_uri = nautilus_get_desktop_directory_uri ();
+		parent_uri = gnome_vfs_uri_new (desktop_dir_uri);
+		g_free (desktop_dir_uri);
+	} else {
+		parent_uri = gnome_vfs_uri_new (parent_dir);
+	}
+
+	/* localizers: the initial name of a new folder  */
 	dirname = g_filename_from_utf8 (_("untitled folder"), -1, NULL, NULL, NULL);
 	uri = gnome_vfs_uri_append_file_name (parent_uri, dirname);
 	g_free (dirname);
@@ -2558,8 +2605,26 @@ nautilus_file_operations_new_file_from_template (GtkWidget *parent_view,
 	g_assert (parent_dir != NULL);
 	g_assert (template_uri != NULL);
 
+	nautilus_debug_log (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER,
+			    "create new file \"%s\" from template \"%s\" in \"%s\"",
+			    target_filename ? target_filename : "(none)", template_uri, parent_dir);
+
 	/* pass in the target directory and the new folder name as a destination URI */
-	parent_uri = gnome_vfs_uri_new (parent_dir);
+	if (eel_uri_is_desktop (parent_dir)) {
+		tmp = nautilus_get_desktop_directory_uri ();
+		parent_uri = gnome_vfs_uri_new (tmp);
+		g_free (tmp);
+	} else if (eel_uri_is_trash (parent_dir) ||
+		   eel_uri_is_search (parent_dir)) {
+		parent_uri = NULL;
+	} else {
+		parent_uri = gnome_vfs_uri_new (parent_dir);
+	}
+
+	if (parent_uri == NULL) {
+		(*done_callback) (NULL, data);
+		return;
+	}
 
 	source_uri = gnome_vfs_uri_new (template_uri);
 	if (source_uri == NULL) {
@@ -2593,7 +2658,7 @@ nautilus_file_operations_new_file_from_template (GtkWidget *parent_view,
 	target_uri_list = g_list_prepend (NULL, target_uri);
 	source_uri_list = g_list_prepend (NULL, source_uri);
 
-	options = GNOME_VFS_XFER_USE_UNIQUE_NAMES;
+	options = GNOME_VFS_XFER_USE_UNIQUE_NAMES | GNOME_VFS_XFER_TARGET_DEFAULT_PERMS;
 
 	gnome_vfs_async_xfer (&state->handle, source_uri_list, target_uri_list,
 	      		      options,
@@ -2647,6 +2712,10 @@ nautilus_file_operations_new_file (GtkWidget *parent_view,
 	char *target_filename;
 	int fd;
 
+	nautilus_debug_log (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER,
+			    "create new file in \"%s\"",
+			    parent_dir);
+
 	fd = mkstemp (source_file_str);
 	if (fd == -1) {
 		(*done_callback) (NULL, data);
@@ -2693,6 +2762,9 @@ nautilus_file_operations_delete (const GList *item_uris,
 	NautilusFile *file;
 	TransferInfo *transfer_info;
 
+	nautilus_debug_log_with_uri_list (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER, item_uris,
+					  "delete files:");
+
 	uri_list = NULL;
 	for (p = item_uris; p != NULL; p = p->next) {
 		item_uri = (const char *) p->data;
@@ -2757,6 +2829,9 @@ do_empty_trash (GtkWidget *parent_view)
 	TransferInfo *transfer_info;
 	GList *trash_dir_list;
 
+	nautilus_debug_log (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER,
+			    "empty trash");
+
 	trash_dir_list = nautilus_trash_monitor_get_trash_directories ();
 	if (trash_dir_list != NULL) {
 		/* set up the move parameters */
